@@ -13,7 +13,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA.
  *
  *
  * The Totem project hereby grant permission for non-gpl compatible GStreamer
@@ -32,7 +32,6 @@
 G_BEGIN_DECLS
 
 void totem_setup_preferences (Totem *totem);
-void totem_preferences_tvout_setup (Totem *totem);
 void totem_preferences_visuals_setup (Totem *totem);
 
 GtkWidget * bacon_cd_selection_create (void);
